@@ -4,7 +4,7 @@ import time
 from uuid import uuid4
 
 import grpc
-from preseem.preseem_model import BaseModelObject
+from ._apiutil import BaseModelObject
 from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 
